package com.chelvc.framework.upload;

import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;

import com.qcloud.cos.model.ObjectMetadata;

/**
 * 文件上传操作接口
 *
 * @author Woody
 * @date 2023/4/5
 */
public interface UploadHandler {
    /**
     * 文件上传
     *
     * @param file 文件对象
     * @return 文件访问地址
     */
    String upload(File file);

    /**
     * 文件上传
     *
     * @param stream   文件流
     * @param filename 文件名
     * @return 文件访问地址
     */
    String upload(InputStream stream, String filename);

    /**
     * 文件上传
     *
     * @param stream   文件流
     * @param filename 文件名
     * @param size     文件大小
     * @return 文件访问地址
     */
    String upload(InputStream stream, String filename, long size);

    /**
     * 文件上传
     *
     * @param stream   文件流
     * @param filename 文件名
     * @param metadata 文件信息
     * @return 文件访问地址
     */
    String upload(InputStream stream, String filename, ObjectMetadata metadata);

    /**
     * 图片上传
     *
     * @param image 图片流
     * @return 文件访问地址
     * @throws IOException I/O异常
     */
    String upload(BufferedImage image) throws IOException;
}
